package com.jiuqi.util;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.jar.Attributes;
import java.util.jar.JarFile;
import java.util.jar.Manifest;
import org.eclipse.osgi.util.ManifestElement;

/* loaded from: com_jiuqi_util.jar:com/jiuqi/util/ManifestUtil.class */
public class ManifestUtil {
    public static final String MANIFEST_FILE_PATH = "/META-INF/MANIFEST.MF";

    public static Manifest getManifest(String path) {
        return getManifest(new File(path));
    }

    public static Manifest getManifest(File file) {
        if (file == null || !file.exists()) {
            return null;
        }
        if (file.isDirectory()) {
            return getManifestFromDir(file);
        }
        if (file.isFile()) {
            return getManifestFromJar(file);
        }
        return null;
    }

    public static Manifest getManifestFromDir(String path) {
        Manifest manifest;
        try {
            InputStream in = new FileInputStream(String.valueOf(path) + MANIFEST_FILE_PATH);
            manifest = new Manifest(in);
        } catch (IOException unused) {
            manifest = null;
        }
        return manifest;
    }

    public static Manifest getManifestFromDir(File file) {
        return getManifestFromDir(file.getAbsolutePath());
    }

    public static Manifest getManifestFromJar(String path) {
        return getManifestFromJar(new File(path));
    }

    public static Manifest getManifestFromJar(File file) {
        Manifest manifest;
        try {
            JarFile jar = new JarFile(file);
            manifest = jar.getManifest();
        } catch (IOException unused) {
            manifest = null;
        }
        return manifest;
    }

    public static void saveManifest(String path, Manifest manifest) {
        try {
            OutputStream out = new FileOutputStream(String.valueOf(path) + MANIFEST_FILE_PATH);
            manifest.write(out);
            out.close();
        } catch (FileNotFoundException unused) {
        } catch (IOException unused2) {
        }
    }

    public static String getAttributeRawValue(Attributes attributes, String attributeName) {
        return attributes.getValue(attributeName);
    }

    public static String getAttributeValue(Attributes attributes, String attributeName) {
        String[] values = getAttributeValues(attributes, attributeName);
        if (values.length > 0) {
            return values[0];
        }
        return null;
    }

    public static String[] getAttributeValues(Attributes attributes, String attributeName) {
        String rawValue = getAttributeRawValue(attributes, attributeName);
        if (rawValue == null) {
            return new String[0];
        }
        String[] values = (String[]) null;
        try {
            ManifestElement[] elements = ManifestElement.parseHeader(attributeName, rawValue);
            values = new String[elements.length];
            for (int i = 0; i < elements.length; i++) {
                values[i] = elements[i].getValue();
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        if (values == null) {
            values = new String[0];
        }
        return values;
    }
}
